#
# spec file for package amsynth
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           amsynth
Version:        1.8.0
Release:        lp150.2.1
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            http://amsynth.github.io/
Source:         https://github.com/amsynth/amsynth/releases/download/release-%{version}/%{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM amsynth-install-translated-appdata.patch badshah400@gmail.com -- Fix installation of translated metainfo for plugins; patch sent upstream
Patch0:         amsynth-install-translated-appdata.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pandoc
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dssi)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(sndfile)
Recommends:     %{name}-lang

%description
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

%package plugin-dssi
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name} = %{version}
Requires:       dssi

%description plugin-dssi
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

This package includes the DSSI implementation of the synthesizer.

%package plugin-lv2
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name} = %{version}

%description plugin-lv2
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

This package includes the LV2 implementation of the synthesizer.

%package plugin-vst
Summary:        Analog modelling (a.k.a virtual analog) software synthesizer
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name} = %{version}

%description plugin-vst
Amsynth is an analog modelling (a.k.a virtual analog) software synthesizer.
It mimics the operation of early analog subtractive synthesizers with
classic oscillator waveforms, envelopes, filter, modulation and effects.
The aim is to make it easy to create and modify sounds.

Features:
 * Dual oscillators (sine / saw / square / noise) with hard sync
 * 12/24 dB/oct resonant filter (low-pass / high-pass / band-pass / notch)
 * Mono / poly / legato keyboard modes
 * Dual ADSR envelope generators (filter & amplitude)
 * LFO which can modulate the oscillators, filter, and amplitude
 * Distortion and reverb
 * Hundreds of presets

There are currently several different ways to run amsynth:
 * Stand-alone application using JACK, ALSA or OSS
 * DSSI plug-in
 * LV2 plug-in
 * VST plug-in

This package includes the VST implementation of the synthesizer.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fv
%configure
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file %{name} Audio Midi
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/%{name}/skins/

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%license COPYING
%doc AUTHORS README NEWS
%{_bindir}/amsynth
%{_datadir}/amsynth
%{_datadir}/applications/amsynth.desktop
%{_datadir}/icons/hicolor/*/apps/amsynth.*
%dir %{_datadir}/appdata
%{_datadir}/appdata/amsynth.appdata.xml
%{_mandir}/man1/amsynth.1%{?ext_man}

%files plugin-dssi
%{_libdir}/dssi/
%dir %{_datadir}/appdata
%{_datadir}/appdata/dssi-amsynth-plugin.metainfo.xml

%files plugin-lv2
%{_libdir}/lv2/
%dir %{_datadir}/appdata
%{_datadir}/appdata/lv2-amsynth-plugin.metainfo.xml

%files plugin-vst
%{_libdir}/vst/
%dir %{_datadir}/appdata
%{_datadir}/appdata/vst-amsynth-plugin.metainfo.xml

%files lang -f %{name}.lang
%{_mandir}/de/man1/amsynth.1%{?ext_man}
%{_mandir}/fr/man1/amsynth.1%{?ext_man}

%changelog
* Tue Apr  3 2018 tchvatal@suse.com
- Use %%license macro
- Drop lash-1.0 dependency as we try to reduce it (remove from TW)
* Mon Jun 26 2017 badshah400@gmail.com
- Update to version 1.8.0:
  + Controls can now be reset to their default value via a
    double-click.
  + Alternate tuning scales & keyboard maps can now be loaded in
    plug-ins.
  + Fixed an issue where bank switching via MIDI caused jack
    zombification.
  + Removed dependency on gtkmm (gtk is still required for the
    UI).
- Add amsynth-install-translated-appdata.patch to fix installation
  of translated metainfo files; introduces BuildRequries on
  automake, autconf and libtool. Patch sent upstream.
- Package metainfo files for plugins.
- Drop BuildRequries on gtkmm.
* Wed Mar 29 2017 badshah400@gmail.com
- Update to version 1.7.1:
  + Fixed MIDI channel filtering.
  + Fixed corrupt preset names in dssi plugin.
  + General UI and menu item improvements.
  + Improvements to translations.
  + Added a man page.
- Drop amsynth-install-appdata.patch (and associated buildrequires
  on libtool): incorporated upstream.
- Generate (add BuildRequires: pandoc) and install new man files
  (new in version 1.7.1).
* Tue Nov 15 2016 badshah400@gmail.com
- Initial package.
- Add amsynth-install-appdata.patch: Add a translatable appdata
  file and install it using autotool; patch-feature-opensuse for
  now but sent upstream.
